FlowAlignmentGuide class final
An active alignment guide while dragging: a line in graph coordinates at
position — vertical (x = position, spanning y in [start, end]) when
vertical, horizontal otherwise.
Constructors
- FlowAlignmentGuide({required bool vertical, required double position, required double start, required double end})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override